==> kubernetes-model-core-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/WindowsSecurityContextOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class WindowsSecurityContextOptionsFluentImpl<A extends WindowsSecurityContextOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements WindowsSecurityContextOptionsFluent<A> {

    private String gmsaCredentialSpec;
    private String gmsaCredentialSpecName;
    private String runAsUserName;

    public WindowsSecurityContextOptionsFluentImpl() { 
    }


    public WindowsSecurityContextOptionsFluentImpl(WindowsSecurityContextOptions instance) { 
        this.withGmsaCredentialSpec(instance.getGmsaCredentialSpec()); 
        this.withGmsaCredentialSpecName(instance.getGmsaCredentialSpecName()); 
        this.withRunAsUserName(instance.getRunAsUserName()); 
    }


    public String getGmsaCredentialSpec() {
        return this.gmsaCredentialSpec;
    }

    public A withGmsaCredentialSpec(String gmsaCredentialSpec) {
        this.gmsaCredentialSpec=gmsaCredentialSpec; return (A) this;
    }

    public Boolean hasGmsaCredentialSpec() {
        return this.gmsaCredentialSpec != null;
    }

    public A withNewGmsaCredentialSpec(String arg1) {
        return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(StringBuilder arg1) {
        return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(StringBuffer arg1) {
        return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public String getGmsaCredentialSpecName() {
        return this.gmsaCredentialSpecName;
    }

    public A withGmsaCredentialSpecName(String gmsaCredentialSpecName) {
        this.gmsaCredentialSpecName=gmsaCredentialSpecName; return (A) this;
    }

    public Boolean hasGmsaCredentialSpecName() {
        return this.gmsaCredentialSpecName != null;
    }

    public A withNewGmsaCredentialSpecName(String arg1) {
        return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(StringBuilder arg1) {
        return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(StringBuffer arg1) {
        return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public String getRunAsUserName() {
        return this.runAsUserName;
    }

    public A withRunAsUserName(String runAsUserName) {
        this.runAsUserName=runAsUserName; return (A) this;
    }

    public Boolean hasRunAsUserName() {
        return this.runAsUserName != null;
    }

    public A withNewRunAsUserName(String arg1) {
        return (A)withRunAsUserName(new String(arg1));
    }

    public A withNewRunAsUserName(StringBuilder arg1) {
        return (A)withRunAsUserName(new String(arg1));
    }

    public A withNewRunAsUserName(StringBuffer arg1) {
        return (A)withRunAsUserName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        WindowsSecurityContextOptionsFluentImpl that = (WindowsSecurityContextOptionsFluentImpl) o;
        if (gmsaCredentialSpec != null ? !gmsaCredentialSpec.equals(that.gmsaCredentialSpec) :that.gmsaCredentialSpec != null) return false;
        if (gmsaCredentialSpecName != null ? !gmsaCredentialSpecName.equals(that.gmsaCredentialSpecName) :that.gmsaCredentialSpecName != null) return false;
        if (runAsUserName != null ? !runAsUserName.equals(that.runAsUserName) :that.runAsUserName != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(gmsaCredentialSpec,  gmsaCredentialSpecName,  runAsUserName,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/WindowsSecurityContextOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class WindowsSecurityContextOptionsFluentImpl<A extends WindowsSecurityContextOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements WindowsSecurityContextOptionsFluent<A> {

    private String gmsaCredentialSpec;
    private String gmsaCredentialSpecName;
    private String runAsUserName;

    public WindowsSecurityContextOptionsFluentImpl() {
    }

    public WindowsSecurityContextOptionsFluentImpl(WindowsSecurityContextOptions instance) {
        this.withGmsaCredentialSpec(instance.getGmsaCredentialSpec()); 
        this.withGmsaCredentialSpecName(instance.getGmsaCredentialSpecName()); 
        this.withRunAsUserName(instance.getRunAsUserName()); 
    }

    public String getGmsaCredentialSpec() {
        return this.gmsaCredentialSpec;
    }

    public A withGmsaCredentialSpec(String gmsaCredentialSpec) {
        this.gmsaCredentialSpec=gmsaCredentialSpec; return (A) this;
    }

    public Boolean hasGmsaCredentialSpec() {
        return this.gmsaCredentialSpec != null;
    }

    public A withNewGmsaCredentialSpec(StringBuilder arg1) {
        return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(int[] arg1,int arg2,int arg3) {
        return (A)withGmsaCredentialSpec(new String(arg1, arg2, arg3));
    }

    public A withNewGmsaCredentialSpec(char[] arg1) {
        return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(StringBuffer arg1) {
        return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(byte[] arg1,int arg2) {
        return (A)withGmsaCredentialSpec(new String(arg1, arg2));
    }

    public A withNewGmsaCredentialSpec(byte[] arg1) {
        return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(char[] arg1,int arg2,int arg3) {
        return (A)withGmsaCredentialSpec(new String(arg1, arg2, arg3));
    }

    public A withNewGmsaCredentialSpec(byte[] arg1,int arg2,int arg3) {
        return (A)withGmsaCredentialSpec(new String(arg1, arg2, arg3));
    }

    public A withNewGmsaCredentialSpec(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withGmsaCredentialSpec(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewGmsaCredentialSpec(String arg1) {
        return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public String getGmsaCredentialSpecName() {
        return this.gmsaCredentialSpecName;
    }

    public A withGmsaCredentialSpecName(String gmsaCredentialSpecName) {
        this.gmsaCredentialSpecName=gmsaCredentialSpecName; return (A) this;
    }

    public Boolean hasGmsaCredentialSpecName() {
        return this.gmsaCredentialSpecName != null;
    }

    public A withNewGmsaCredentialSpecName(StringBuilder arg1) {
        return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(int[] arg1,int arg2,int arg3) {
        return (A)withGmsaCredentialSpecName(new String(arg1, arg2, arg3));
    }

    public A withNewGmsaCredentialSpecName(char[] arg1) {
        return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(StringBuffer arg1) {
        return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(byte[] arg1,int arg2) {
        return (A)withGmsaCredentialSpecName(new String(arg1, arg2));
    }

    public A withNewGmsaCredentialSpecName(byte[] arg1) {
        return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(char[] arg1,int arg2,int arg3) {
        return (A)withGmsaCredentialSpecName(new String(arg1, arg2, arg3));
    }

    public A withNewGmsaCredentialSpecName(byte[] arg1,int arg2,int arg3) {
        return (A)withGmsaCredentialSpecName(new String(arg1, arg2, arg3));
    }

    public A withNewGmsaCredentialSpecName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withGmsaCredentialSpecName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewGmsaCredentialSpecName(String arg1) {
        return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public String getRunAsUserName() {
        return this.runAsUserName;
    }

    public A withRunAsUserName(String runAsUserName) {
        this.runAsUserName=runAsUserName; return (A) this;
    }

    public Boolean hasRunAsUserName() {
        return this.runAsUserName != null;
    }

    public A withNewRunAsUserName(StringBuilder arg1) {
        return (A)withRunAsUserName(new String(arg1));
    }

    public A withNewRunAsUserName(int[] arg1,int arg2,int arg3) {
        return (A)withRunAsUserName(new String(arg1, arg2, arg3));
    }

    public A withNewRunAsUserName(char[] arg1) {
        return (A)withRunAsUserName(new String(arg1));
    }

    public A withNewRunAsUserName(StringBuffer arg1) {
        return (A)withRunAsUserName(new String(arg1));
    }

    public A withNewRunAsUserName(byte[] arg1,int arg2) {
        return (A)withRunAsUserName(new String(arg1, arg2));
    }

    public A withNewRunAsUserName(byte[] arg1) {
        return (A)withRunAsUserName(new String(arg1));
    }

    public A withNewRunAsUserName(char[] arg1,int arg2,int arg3) {
        return (A)withRunAsUserName(new String(arg1, arg2, arg3));
    }

    public A withNewRunAsUserName(byte[] arg1,int arg2,int arg3) {
        return (A)withRunAsUserName(new String(arg1, arg2, arg3));
    }

    public A withNewRunAsUserName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withRunAsUserName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewRunAsUserName(String arg1) {
        return (A)withRunAsUserName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        WindowsSecurityContextOptionsFluentImpl that = (WindowsSecurityContextOptionsFluentImpl) o;
        if (gmsaCredentialSpec != null ? !gmsaCredentialSpec.equals(that.gmsaCredentialSpec) :that.gmsaCredentialSpec != null) return false;
        if (gmsaCredentialSpecName != null ? !gmsaCredentialSpecName.equals(that.gmsaCredentialSpecName) :that.gmsaCredentialSpecName != null) return false;
        if (runAsUserName != null ? !runAsUserName.equals(that.runAsUserName) :that.runAsUserName != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(gmsaCredentialSpec,  gmsaCredentialSpecName,  runAsUserName,  super.hashCode());
    }

}
